@@ -34,7 +34,7 @@
 #include "indent.h"
 #include "globs.h"
 
-RCSTAG_CC ("$Id: lexi.c,v 1.32 2001/11/26 21:50:49 david Exp $");
+RCSTAG_CC ("$Id: lexi.c,v 1.34 2002/03/04 20:31:30 david Exp $");
 
 /* Stuff that needs to be shared with the rest of indent. Documented in
  * indent.h.  */
@@ -44,14 +44,14 @@ char *token_end;
 #define alphanum 1
 #define opchar 3
 
-struct templ
+typedef struct templ
 {
-  char *rwd;
-  enum rwcodes rwcode;
-};
+  char     * rwd;
+  rwcodes_ty rwcode;
+} templ_ty;
 
 /* Pointer to a vector of keywords specified by the user.  */
-static struct templ *user_specials = 0;
+static templ_ty *user_specials = 0;
 
 /* Allocated size of user_specials.  */
 static unsigned int user_specials_max;
@@ -59,9 +59,11 @@ static unsigned int user_specials_max;
 /* Index in user_specials of the first unused entry.  */
 static unsigned int user_specials_idx;
 
-char chartype[] = {		/* this is used to facilitate the decision of
-				   what type (alphanumeric, operator) each
-				   character is */
+char chartype[] =
+{
+    /* this is used to facilitate the decision of
+     * what type (alphanumeric, operator) each
+     * character is */
 #ifndef CHARSET_EBCDIC
 
   0, 0, 0, 0, 0, 0, 0, 0,
@@ -149,8 +151,7 @@ char chartype[] = {		/* this is used to facilitate the decision of
  * but the few non-zero places should be compatible with IBM's EBCDIC.
  */
 #if 0
-int
-main (void)
+int main (void)
 {
     const int GAP = 8;
     int i, j;
@@ -177,12 +178,11 @@ main (void)
 #endif
 
 /* Include code generated by gperf */
-#ifdef PROTOTYPES
 #ifdef __GNUC__
 __inline
 #endif
-struct templ *is_reserved (register const char *str, register unsigned int len);
-#endif
+templ_ty *is_reserved (register const char *str, register unsigned int len);
+
 #include "gperf.c"
 
 /* Include code generated by gperf for C++ keyword set */
@@ -192,34 +192,35 @@ struct templ *is_reserved (register const char *str, register unsigned int len);
 #undef MIN_WORD_LENGTH
 #undef MAX_WORD_LENGTH
 
-#ifdef PROTOTYPES
 #ifdef __GNUC__
 __inline
 #endif
-struct templ *is_reserved_cc (register const char *str, register unsigned int len);
-#endif
+templ_ty *is_reserved_cc (register const char *str, register unsigned int len);
+
 #include "gperf-cc.c"
 
-enum codes lexi (void)
+codes_ty lexi (void)
 {
-    int unary_delim;		/* this is set to 1 if the current token
-				   forces a following operator to be unary */
-    static enum codes last_code;	/* the last token type returned */
-    static int l_struct;		/* set to 1 if the last token was 'struct' */
-    static int l_enum;		/* set to 1 if the last token was `enum' */
-    enum codes code;		/* internal code to be returned */
-    char qchar;			/* the delimiter character for a string */
+    int             unary_delim;/* this is set to 1 if the current token
+                                 * forces a following operator to be unary */
+    static codes_ty last_code;	/* the last token type returned */
+    static int      l_struct;   /* set to 1 if the last token was 'struct' */
+    static int      l_enum;	/* set to 1 if the last token was `enum' */
+    codes_ty        code;	/* internal code to be returned */
+    char            qchar;      /* the delimiter character for a string */
 
-    static int count;		/* debugging counter */
+    static int      count;	/* debugging counter */
 
     count++;
 
     unary_delim = false;
+    
     /* tell world that this token started in column 1 iff the last
-       thing scanned was nl */
-    parser_state_tos->col_1 = parser_state_tos->last_nl;
+     * thing scanned was nl */
+    
+    parser_state_tos->col_1       = parser_state_tos->last_nl;
     parser_state_tos->last_saw_nl = parser_state_tos->last_nl;
-    parser_state_tos->last_nl = false;
+    parser_state_tos->last_nl     = false;
 
     if (buf_ptr >= buf_end)
     {
@@ -254,7 +255,7 @@ enum codes lexi (void)
         ((buf_ptr[0] == '.') && isdigit (buf_ptr[1])))
     {
         /* we have a character or number */
-        struct templ *p;
+        templ_ty *p;
 
         if (isdigit (*buf_ptr) ||
             ((buf_ptr[0] == '.') && isdigit (buf_ptr[1])))
@@ -394,7 +395,7 @@ enum codes lexi (void)
 
         /* Check whether the token is a reserved word.  Use perfect hashing... */
         
-        if (c_plus_plus)
+        if (settings.c_plus_plus)
         {
             p = is_reserved_cc (token, token_end - token);
         }
@@ -449,13 +450,13 @@ enum codes lexi (void)
 
         if (p)
 	{			/* we have a keyword */
-            enum codes value;
+            codes_ty value;
 
 	found_keyword:
             value = ident;
             parser_state_tos->its_a_keyword = true;
-            parser_state_tos->last_u_d = true;
-            parser_state_tos->last_rw = p->rwcode;
+            parser_state_tos->last_u_d      = true;
+            parser_state_tos->last_rw       = p->rwcode;
             parser_state_tos->last_rw_depth = parser_state_tos->paren_depth;
             
             switch (p->rwcode)
@@ -501,7 +502,7 @@ enum codes lexi (void)
                     value = (sp_paren);
                     if (*token == 'i' && parser_state_tos->last_token == sp_else)
                     {
-                        parser_state_tos->i_l_follow -= ind_size;
+                        parser_state_tos->i_l_follow -= settings.ind_size;
                     }
                     
                     break;
@@ -811,7 +812,7 @@ enum codes lexi (void)
 
             /* Make spaces between '#' and the directive be part of
                the token if user specified "-lps" */
-            if (leave_preproc_space)
+            if (settings.leave_preproc_space)
             {
                 while (*buf_ptr == ' ' && buf_ptr < buf_end)
                 {
@@ -879,7 +880,7 @@ enum codes lexi (void)
                  *   ONE,
                  *     TWO,
                  * Use a special code for `block_init' however, because we still
-                 * want to do the line breaks when `braces_on_struct_decl_line'
+                 * want to do the line breaks when `settings.braces_on_struct_decl_line'
                  * is not set.
                  */
                 parser_state_tos->block_init = 2;
@@ -1016,7 +1017,7 @@ enum codes lexi (void)
             /* in C++ mode also scan <?[=], >?[=] GNU C++ operators 
              * maybe some flag to them ? */
             
-            while (*buf_ptr == '>' || *buf_ptr == '<' || *buf_ptr == '=' || (c_plus_plus && *buf_ptr == '?'))
+            while (*buf_ptr == '>' || *buf_ptr == '<' || *buf_ptr == '=' || (settings.c_plus_plus && *buf_ptr == '?'))
             {
                 if (++buf_ptr >= buf_end)
                 {
@@ -1126,30 +1127,29 @@ enum codes lexi (void)
 /* Add the given keyword to the keyword table, using val as
  * the keyword type */
 
-void
-addkey (
-        char *key,
-        enum rwcodes val)
+void addkey (
+    char *key,
+    rwcodes_ty val)
 {
-    struct templ *p;
+    templ_ty *p;
 
     /* Check to see whether key is a reserved word or not. */
-    if ( (c_plus_plus  && is_reserved_cc (key, strlen (key)) != 0) ||
-         (!c_plus_plus && is_reserved (key, strlen (key)) != 0))
+    if ( (settings.c_plus_plus  && is_reserved_cc (key, strlen (key)) != 0) ||
+         (!settings.c_plus_plus && is_reserved (key, strlen (key)) != 0))
     {
         return;
     }
 
     if (user_specials == 0)
     {
-        user_specials = (struct templ *) xmalloc (5 * sizeof (struct templ));
+        user_specials = (templ_ty *) xmalloc (5 * sizeof (templ_ty));
         user_specials_max = 5;
         user_specials_idx = 0;
     }
     else if (user_specials_idx == user_specials_max)
     {
         user_specials_max += 5;
-        user_specials = (struct templ *) xrealloc ((char *) user_specials, user_specials_max * sizeof (struct templ));
+        user_specials = (templ_ty *) xrealloc ((char *) user_specials, user_specials_max * sizeof (templ_ty));
     }
 
     p = &user_specials[user_specials_idx++];
